@@ -2,6 +2,7 @@
 
 /* 
  * Copyright (C) 2001 Havoc Pennington
+ * Copyright (C) 2005 Elijah Newren
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -64,7 +65,8 @@ typedef enum
   META_MENU_OP_MOVE_LEFT   = 1 << 13,
   META_MENU_OP_MOVE_RIGHT  = 1 << 14,
   META_MENU_OP_MOVE_UP     = 1 << 15,
-  META_MENU_OP_MOVE_DOWN   = 1 << 16
+  META_MENU_OP_MOVE_DOWN   = 1 << 16,
+  META_MENU_OP_RECOVER     = 1 << 17
 } MetaMenuOp;
 
 typedef struct _MetaWindowMenu MetaWindowMenu;
@@ -153,6 +155,8 @@ typedef enum
 {
   META_ACTION_DOUBLE_CLICK_TITLEBAR_TOGGLE_SHADE,
   META_ACTION_DOUBLE_CLICK_TITLEBAR_TOGGLE_MAXIMIZE,
+  META_ACTION_DOUBLE_CLICK_TITLEBAR_MINIMIZE,
+  META_ACTION_DOUBLE_CLICK_TITLEBAR_NONE,
   META_ACTION_DOUBLE_CLICK_TITLEBAR_LAST
 } MetaActionDoubleClickTitlebar;
 
@@ -184,6 +188,22 @@ typedef enum
   META_VIRTUAL_MOD5_MASK     = 1 << 14
 } MetaVirtualModifier;
 
+/* Relative directions or sides seem to come up all over the place... */
+/* FIXME: Replace
+ *   place.[ch]:MetaWindowEdgePosition,
+ *   screen.[ch]:MetaScreenDirection,
+ *   workspace.[ch]:MetaMotionDirection,
+ * with the use of MetaDirection.
+ */
+typedef enum
+{
+  META_DIRECTION_LEFT      = 1 << 0,
+  META_DIRECTION_RIGHT     = 1 << 1,
+  META_DIRECTION_TOP       = 1 << 2,
+  META_DIRECTION_BOTTOM    = 1 << 3,
+  META_DIRECTION_UP        = 1 << 2, /* Alternate name for TOP */
+  META_DIRECTION_DOWN      = 1 << 3  /* Alternate name for BOTTOM */
+} MetaDirection;
 
 /* Function a window button can have.  Note, you can't add stuff here
  * without extending the theme format to draw a new function and
@@ -226,7 +246,3 @@ struct _MetaButtonLayout
   (ycoord) <  ((rect).y + (rect).height))
 
 #endif
-
-
-
-
