@@ -26,8 +26,11 @@
 
 /* note, can return NULL */
 MetaGroup* meta_window_get_group       (MetaWindow *window);
+void       meta_window_compute_group   (MetaWindow* window);
 void       meta_window_shutdown_group  (MetaWindow *window);
 
+void       meta_window_group_leader_changed (MetaWindow *window);
+
 /* note, can return NULL */
 MetaGroup* meta_display_lookup_group   (MetaDisplay *display,
                                         Window       group_leader);
@@ -36,6 +39,11 @@ GSList*    meta_group_list_windows     (MetaGroup *group);
 
 void       meta_group_update_layers    (MetaGroup *group);
 
+const char* meta_group_get_startup_id  (MetaGroup *group);
+
+gboolean meta_group_property_notify   (MetaGroup  *group,
+                                       XEvent     *event);
+
 #endif
 
 
