@@ -28,6 +28,10 @@
 #include <X11/Xatom.h>
 #include <unistd.h>
 #include <string.h>
+#ifndef HOST_NAME_MAX
+/* Solaris headers apparently don't define this so do so manually; #326745 */
+#define HOST_NAME_MAX 255
+#endif
 
 typedef void (* InitValueFunc)   (MetaDisplay   *display,
                                   Atom           property,
@@ -162,7 +166,7 @@ reload_net_wm_pid (MetaWindow    *window,
       gulong cardinal = (int) value->v.cardinal;
       
       if (cardinal <= 0)
-        meta_warning (_("Application set a bogus _NET_WM_PID %ld\n"),
+        meta_warning (_("Application set a bogus _NET_WM_PID %lu\n"),
                       cardinal);
       else
         {
